//________________________________________________________________________________________________________
//	
//	Fichero de idiomas javascript: aulas_eng.js 
//	Idioma: Ingés 
//________________________________________________________________________________________________________
TbMsg=new Array;
TbMsg[0]="Computer template have been successfully registered and all the computers of this lab have been updated using this configuration";
TbMsg[1]="WARNING: This environment will be refresh. ¿ Are you sure ?";
TbMsg[2]="WARNING: This environment will be purge. ¿ Are you sure ?";
TbMsg[3]="WARNING: the items of menus from this environment will be refresh. ¿ Are you sure ?";
