//________________________________________________________________________________________________________
//
//	Fichero de idiomas javascripts: comunescomandos_eng.js (Común a todos los comandos)
//	Idioma: Ingés 
//________________________________________________________________________________________________________
CTbMsg=new Array;
CTbMsg[0]="WARNING.- Cancelled operation, you will might come back this screen in another moment to perform this command";
CTbMsg[1]="WARNING: An error occurs when attempt to register command";
CTbMsg[2]="The command has been successfully registered";
