<?
//________________________________________________________________________________________________________
//
//	Fitxer d'idiomes php: propiedades_ordenadorestandar_esp.php 
//	Idioma: Català 
//________________________________________________________________________________________________________
$TbMsg=array();
$TbMsg[0]="Aula";
$TbMsg[1]="Ordinador plantilla";
$TbMsg[2]="Nom";
$TbMsg[3]="Direcció IP";
$TbMsg[4]="Direcció MAC";
$TbMsg[5]="Perfil hardware";
$TbMsg[6]="Servidor Dhcp";
$TbMsg[7]="Servidor Rembo ";
$TbMsg[8]="Ordinadors per a insertar";
$TbMsg[9]='(*) Per a modificar un ordinador amb un certa dada, en aquest'aula, deu introduir el valor corresponent i deixar el camp "Ordinadors a insertar" a zero.';
$TbMsg[10]="(**)Si es tracta de ordinadors nous amb una configuració per defecte, pero no vol modificar els ordinadors ja existents deu introduir un valor mes gran que zero.";
$TbMsg[11]="Tamany Caché";

?>
