<?
//________________________________________________________________________________________________________
//
//	Fitxer d'idiomes php: propiedades_aulas_esp.php 
//	Idioma: Catala 
//________________________________________________________________________________________________________
$TbMsg=array();
$TbMsg[0]="Sense Opcio";
$TbMsg[1]="Insertar";
$TbMsg[2]="Modificar";
$TbMsg[3]="Eliminar";
$TbMsg[4]="Gestio Aules";
$TbMsg[5]="Nom";
$TbMsg[6]="Ubicacio";
$TbMsg[7]="Canon";
$TbMsg[8]="Pissarra";
$TbMsg[9]="Puestos";
$TbMsg[10]="Url Imatge";
$TbMsg[11]="Menu";
$TbMsg[12]="Comentaris";
$TbMsg[13]="Intervals";
$TbMsg[14]="Hora desde:";
$TbMsg[15]="Hora fins:";
$TbMsg[16]="Repositorio";
$TbMsg[17]="Perfil Hardware";
$TbMsg[18]="Propietat pert tot els ordinadors";
$TbMsg[19]="Tamaño caché (KB)";
$TbMsg[20]="Autoexec";
$TbMsg[21]="";
$TbMsg[22]="Modo Multicast";
$TbMsg[23]="IP Multicast";
$TbMsg[24]="Port Multicast";
$TbMsg[25]="Velocidat Multicast";
$TbMsg[26]="Modo P2P -semillero durante la descarga-";
$TbMsg[27]="Temp P2P -semillero despres de descarga-";
$TbMsg[28]="adresa gateway del aule";
$TbMsg[29]="Mascara de la xarxa del aule";
?>