<?
//________________________________________________________________________________________________________
//
//	Fitxer d'idiomes php: informacion_menus_esp.php 
//	Idioma: Català 
//________________________________________________________________________________________________________
	$TbMsg=array();
	$TbMsg[0]='Items del Menu';
	$TbMsg[1]='Informació del Menú';
	$TbMsg[2]='Menú';
	$TbMsg[3]='Informació Menú';
	$TbMsg[4]='Propietats de los items';
	$TbMsg[5]='Propietats';
	$TbMsg[6]='Eliminar Item';
	$TbMsg[7]='Títul';
	$TbMsg[8]='Propietats de los items públics del Menú';
	$TbMsg[9]='Coordenada x';
	$TbMsg[10]='Coordenada y';
	$TbMsg[11]='Modalitat';
	$TbMsg[12]='Propietats de los items privats del Menú';
	$TbMsg[13]='Items públics ';
	$TbMsg[14]='Items privats';
	$TbMsg[15]='Orden del item';
	$TbMsg[16]='Literal del item';
	$TbMsg[17]='Nombre de la Imatge';
	$TbMsg[18]='Menú simple';
	$TbMsg[19]='Menú doble';
	$TbMsg[20]='Códi del item';
?>