.textos{
	COLOR: #A53B2D;
	FONT-FAMILY:MS Sans Serif;
	FONT-SIZE: 8pt;
}

.texto_arbol{
    COLOR: #000000;
    FONT-FAMILY: sans-serif;
    FONT-SIZE: 11px;
}

.menu_contextual TABLE{
    BACKGROUND-COLOR: #d4d0c8;
}

.menu_contextual TD{
    COLOR: #000000;
    FONT-FAMILY: Verdana, Arial, Helvetica, sans-serif;
    FONT-SIZE: 11px;
    LETTER-SPACING: -1px;
}
.menu_contextual SPAN{
    COLOR: #000000;
    FONT-FAMILY: Verdana, Arial, Helvetica, sans-serif;
    FONT-SIZE: 11px;
    LETTER-SPACING: -1px;
}
.tabla_standar TD{
    COLOR: #000000;
    FONT-FAMILY: Verdana;
    FONT-SIZE: 11px;
}

.tabla_lista TD{
    COLOR: #000000;
    FONT-FAMILY: Verdana;
    FONT-SIZE: 11px;
    LETTER-SPACING: -1px;
}

.input_nodo{
    BORDER-BOTTOM: 1px solid;
    BORDER-LEFT: 1px solid;
    BORDER-RIGHT: 1px solid;
    BORDER-TOP: 1px solid;
    COLOR: #000000;
    FONT-SIZE: 11px;
    HEIGHT: 14px;
}
.marcorelieve{
    BORDER-BOTTOM: #808080 1px solid;
    BORDER-LEFT: #ffffff 1px solid;
    BORDER-RIGHT: #808080 1px solid;
    BORDER-TOP: #ffffff 1px solid;
}
.marco{
    BORDER-BOTTOM: #999999 1px solid;
    BORDER-LEFT: #999999 1px solid;
    BORDER-RIGHT: #999999 1px solid;
    BORDER-TOP: #999999 1px solid;
    COLOR: #000000;
    FONT-FAMILY: Verdana,Arial, Helvetica, sans-serif;
    FONT-SIZE: 13px;
}
.menupral{
    BACKGROUND-COLOR: #d4d0c8;
    FONT-FAMILY: sans-serif;
    FONT-SIZE: 11px;
}
.menupral TD{
    BORDER-BOTTOM: #d4d0c8 1px solid;
    BORDER-LEFT: #d4d0c8 1px solid;
    BORDER-RIGHT: #d4d0c8 1px solid;
    BORDER-TOP: #d4d0c8 1px solid;
}

.menupral SPAN{
    COLOR: #000000;
    FONT-FAMILY: sans-serif;
    FONT-SIZE: 11px;
}

.filtros{
    BORDER-BOTTOM: #999999 1px solid;
    BORDER-LEFT: #999999 1px solid;
    BORDER-RIGHT: #999999 1px solid;
    BORDER-TOP: #999999 1px solid;
}

.filtros TD{
  FONT-FAMILY: sans-serif;
  FONT-SIZE: 11px;
	COLOR:#999999;
}
.supercabeceras {
	COLOR:#FE6C65; 
	FONT-FAMILY: Arial;
	FONT-SIZE: 30px;
	FONT-WEIGHT: 600;
}
.sobrecabeceras {
	COLOR:#7575DD; 
	FONT-FAMILY: Arial;
	FONT-SIZE: 24px;
	FONT-WEIGHT: 400;
}
.cabeceras{
    COLOR: #999999;
    FONT-FAMILY: Verdana;
    FONT-SIZE: 24px;
	FONT-WEIGHT: 600;
}
.subcabeceras{
	COLOR: #D6A621;
    FONT-FAMILY: Verdana;
    FONT-SIZE: 20px;
}

.presentaciones{
    COLOR: #999999;
    FONT-FAMILY: Verdana,Arial, Helvetica, sans-serif;
    FONT-SIZE: 12px;
}


.notas{
    COLOR: #999999;
    FONT-FAMILY: Arial, Helvetica, sans-serif;
    FONT-SIZE: 10px;
}

.tabla_datos{
}

.tabla_datos TH{
    BACKGROUND-COLOR: #63676b;
    COLOR: #ffffff;
    FONT-FAMILY:  Arial, Helvetica, sans-serif;
    FONT-SIZE: 12px;
    FONT-WEIGHT: 500;
	BORDER-BOTTOM:#999999 1px solid ;
}

.tabla_datos TD{
    BACKGROUND-COLOR: #d4d0c8;
    COLOR: #003300;
    FONT-FAMILY: Arial, Helvetica, sans-serif;
    FONT-SIZE: 12px;
	BORDER-BOTTOM:#999999 1px solid;
}

.formulariodatos{
    COLOR: #000000;
    FONT-FAMILY: Arial, Helvetica, sans-serif;
    FONT-SIZE: 11px
}

.tabla_listados{
}

.tabla_listados TH{
    BACKGROUND-COLOR: #63676b;
    COLOR: #ffffff;
    FONT-FAMILY:  Arial, Helvetica, sans-serif;
    FONT-SIZE: 12px;
    FONT-WEIGHT: 500;
	BORDER-BOTTOM:#999999 1px solid ;
}
.tabla_listados TD{
    BACKGROUND-COLOR: #EEEECC;
    COLOR: #003300;
    FONT-FAMILY: Arial, Helvetica, sans-serif;
    FONT-SIZE: 11px;
	BORDER-BOTTOM:#999999 1px solid;
}

.tabla_listados_sin {
}

.tabla_listados_sin TH{
    BACKGROUND-COLOR: #63676b;
    COLOR: #ffffff;
    FONT-FAMILY:  Arial, Helvetica, sans-serif;
    FONT-SIZE: 12px;
    FONT-WEIGHT: 500;
 	BORDER-BOTTOM:#4f4f4f 1px solid;   
 	BORDER-RIGHT:#4f4f4f 1px solid; 
}

.tabla_listados_sin TD{
    BACKGROUND-COLOR: #EEEECC;
    COLOR: #000000;
    FONT-FAMILY: Arial, Helvetica, sans-serif;
    FONT-SIZE: 11;
}

A.tabla_listados_sin:visited{
    COLOR: #000000;
    FONT-FAMILY: sans-serif;
    FONT-SIZE: 11px;
}
A.tabla_listados_sin:link{
    COLOR: #000000;
    FONT-FAMILY: sans-serif;
    FONT-SIZE: 11px;
}

.recuadros{    
	BACKGROUND-COLOR: lightseagreen;
    BORDER-BOTTOM: teal solid;
    BORDER-LEFT: #b4e0d2 solid;
    BORDER-RIGHT: teal solid;
    BORDER-TOP: #b4e0d2 solid;
    COLOR: white;
    FONT-STYLE: italic
}

.tabla_meses{
}

.tabla_meses TH{
    BACKGROUND-COLOR: #b5daad;
    COLOR: #000000;
    FONT-FAMILY:  Arial, Helvetica, sans-serif;
    FONT-SIZE: 11px;
    FONT-WEIGHT: 500;
    BORDER-BOTTOM: #999999  1px solid;
    BORDER-LEFT: #999999  1px solid;
    BORDER-RIGHT: #999999 1px solid;
    BORDER-TOP: #999999 1px solid;	
}

.tabla_meses TD{
    BACKGROUND-COLOR: #EEEECC;
    COLOR: #003300;
    FONT-FAMILY: Arial, Helvetica, sans-serif;
    FONT-SIZE: 12px;
    BORDER-BOTTOM: #d4d4d4  1px solid;
    BORDER-LEFT: #d4d4d4  1px solid;

}

.tabla_reservas{
}

.tabla_reservas TH{
    BACKGROUND-COLOR: #B5DAAD;
    COLOR: #000000;
    FONT-FAMILY:  Arial, Helvetica, sans-serif;
    FONT-SIZE: 10px;
    FONT-WEIGHT: 700;
}

.tabla_reservas TD{
    FONT-FAMILY: Arial, Helvetica, sans-serif;
    FONT-SIZE: 10px;

}
.tabla_busquedas{
}

.tabla_busquedas TH{
    BACKGROUND-COLOR: #5a86b5;
    COLOR: #ffffff;
    FONT-FAMILY:  Arial, Helvetica, sans-serif;
    FONT-SIZE: 11px;
    FONT-WEIGHT: 500;
	BORDER-BOTTOM:#000000 1px solid ;
}

.tabla_busquedas TD{
    COLOR: #003300;
    FONT-FAMILY: Arial, Helvetica, sans-serif;
    FONT-SIZE: 11px;
}

.tablaipes{
    BACKGROUND-COLOR: #b5daad;
    FONT-FAMILY: Arial, Helvetica, sans-serif;
    FONT-SIZE: 9px
}

.estilodesple{
    FONT-FAMILY: Arial, Helvetica, sans-serif;
    FONT-SIZE: 11px
}

.cajatexto{
    FONT-FAMILY: Arial, Helvetica, sans-serif;
    FONT-SIZE: 11px
}

.cajacomandos{
	BACKGROUND-COLOR: #ffffff;
    COLOR: #000000;
    FONT-FAMILY: Arial, Helvetica, sans-serif;
    FONT-SIZE: 12px
}
.salidacomandos{
	BACKGROUND-COLOR: #000000;
    COLOR: #ffffff;
    FONT-FAMILY: Arial, Helvetica, sans-serif;
    FONT-SIZE: 12px
}

.tabla_parametros{
}

.tabla_parametros TH{
    BACKGROUND-COLOR: #D4D4D4;
    COLOR: #000000;
    FONT-FAMILY:  Arial, Helvetica, sans-serif;
    FONT-SIZE: 12px;
    FONT-WEIGHT: 700;
	BORDER-BOTTOM:#000000 1px solid ;

}
.tabla_parametros TD{
    BACKGROUND-COLOR: #B5DAAD;
    COLOR: #003300;
    FONT-FAMILY: Arial, Helvetica, sans-serif;
    FONT-SIZE: 11px;
	BORDER-BOTTOM:#000000 1px solid;

}
.opciones_ejecucion{
    BORDER-TOP: silver thin solid;
    BORDER-BOTTOM: silver thin solid;
    BORDER-LEFT: silver thin solid;
    BORDER-RIGHT: silver thin solid;
    FONT-FAMILY:  Arial, Helvetica, sans-serif;
    FONT-SIZE: 11px;
}

.tablaprogramacion TABLE{
}

.tablaprogramacion TH{
	FONT-WEIGHT: bold;
    FONT-FAMILY:  Arial, Helvetica, sans-serif;
    FONT-SIZE: 11px;
	BORDER-LEFT: medium none;
	COLOR: white;
	BACKGROUND-COLOR: lightseagreen;
	TEXT-ALIGN: left;
}

.tablaprogramacion TD{
	FONT-SIZE: 9pt;				    
    FONT-FAMILY:  Arial, Helvetica, sans-serif;
	COLOR: #000000;

}

.botonprogramacion{
	BORDER-BOTTOM: #666666 1px solid;
	BORDER-TOP: #ffffff 1px solid;
	BORDER-LEFT: #ffffff 1px solid;				    				    
	BORDER-RIGHT: #666666 1px solid;
    BACKGROUND-COLOR: #EEEECC;
	FONT-SIZE: 9pt;		
	COLOR: #000000;
    FONT-FAMILY:  Arial, Helvetica, sans-serif;
}

.tabla_accesos{
}

.tabla_accesos TH{
    BACKGROUND-COLOR: lightseagreen;
    COLOR: #ffffff;
    FONT-FAMILY:  Arial, Helvetica, sans-serif;
    FONT-SIZE: 11px;
    FONT-WEIGHT: 500;
	BORDER-BOTTOM:#000000 1px solid ;
}

.tabla_accesos TD{
    COLOR: #003300;
    FONT-FAMILY: Arial, Helvetica, sans-serif;
    FONT-SIZE: 11px;
}
.mensajebrowser{
    BORDER-BOTTOM: #999999 1px solid;
    BORDER-LEFT: #999999 1px solid;
    BORDER-RIGHT: #999999 1px solid;
    BORDER-TOP: #999999 1px solid;
	BACKGROUND-COLOR: #FFFFFF;
    COLOR: #999999;
    FONT-FAMILY:  Arial, Helvetica, sans-serif;
    FONT-SIZE: 14px;
    FONT-WEIGHT: 300;
}

