<?
//________________________________________________________________________________________________________
//
//	Fichero de idiomas php: propiedades_aulas_eng.php 
//	Idioma: Ing�s 
//________________________________________________________________________________________________________
$TbMsg=array();
$TbMsg[0]="No Option";
$TbMsg[1]="Insert";
$TbMsg[2]="Modify";
$TbMsg[3]="Remove";
$TbMsg[4]="Labs Management";
$TbMsg[5]="Lab Name";
$TbMsg[6]="Ubication";
$TbMsg[7]="Cagnon";
$TbMsg[8]="Blackboard";
$TbMsg[9]="Places";
$TbMsg[10]="Image Url";
$TbMsg[11]="Menu";
$TbMsg[12]="Comments";
$TbMsg[13]="Intervals";
$TbMsg[14]="Begin reserves";
$TbMsg[15]="End reserves";
$TbMsg[16]="Repository";
$TbMsg[17]="Hardware profile";
$TbMsg[18]="Properties for all computers in this class";
$TbMsg[19]="Cache Size (KB)";
$TbMsg[20]="Autoexec";
$TbMsg[21]="";
$TbMsg[22]="Multicast mode";
$TbMsg[23]="Multicast IP address";
$TbMsg[24]="Multicast port";
$TbMsg[25]="Multicast bandwith";
$TbMsg[26]="P2P mode -seeder while downloading";
$TbMsg[27]="P2P time -seeder time(s) after download-";
$TbMsg[28]="Gateway";
$TbMsg[29]="Netmask";

?>