<?
//________________________________________________________________________________________________________
//
//	Fichero de idiomas php: propiedades_aulas_esp.php 
//	Idioma: Español 
//________________________________________________________________________________________________________
$TbMsg=array();
$TbMsg[0]="Sin Opción";
$TbMsg[1]="Insertar";
$TbMsg[2]="Modificar";
$TbMsg[3]="Eliminar";
$TbMsg[4]="Gestión Aulas";
$TbMsg[5]="Nombre";
$TbMsg[6]="Ubicación";
$TbMsg[7]="Cañón";
$TbMsg[8]="Pizarra";
$TbMsg[9]="Puestos";
$TbMsg[10]="URL Imagen";
$TbMsg[11]="Menú";
$TbMsg[12]="Comentarios";
$TbMsg[13]="Reservas";
$TbMsg[14]="Hora desde:";
$TbMsg[15]="Hora hasta:";
$TbMsg[16]="Repositorio";
$TbMsg[17]="Perfil Hardware";
$TbMsg[18]="Propiedades aplicables a todos los ordenadores";
$TbMsg[19]="Tamaño caché (KB)";
$TbMsg[20]="Autoexec";
$TbMsg[21]="";
$TbMsg[22]="Modo Multicast";
$TbMsg[23]="IP Multicast";
$TbMsg[24]="Puerto Multicast";
$TbMsg[25]="Velocidad Multicast";
$TbMsg[26]="Modo P2P -semillero durante la descarga-";
$TbMsg[27]="Tiempo P2P -semillero despues de descarga-";
$TbMsg[28]="Direccion gateway del aula";
$TbMsg[29]="Mascara de red del aula";
	

?>
